==> adscounter-facade-1.0.1-sources.jar: com/bxm/adscounter/facade/model/AdGroupCountMsg.java <==
package com.bxm.adscounter.facade.model;

import java.io.Serializable;

/**
 * <p> 广告组统计数据参数 </p>
 *
 * @Author: JandMin
 * @since: 1.0.0
 * @Date: 2018/8/9
 */
public class AdGroupCountMsg implements Serializable{
    private static final long serialVersionUID = -757734782728494378L;
    /**
     * ip地址
     */
    private String ipAddress;
    /**
     * 其它页面信息
     */
    private String param;
    /**
     * 手机号
     */
    private String phone;
    /**
     * 身份证号码
     */
    private String idcardnum;
    /**
     * 广告组标志
     */
    private String shop_code;
    /**
     * 记录ID
     */
    private String bxm_id;
    /**
     * 状态
     */
    private String status;
    /**
     * 类型
     */
    private String modeltype;

    public String getIpAddress() {
        return ipAddress;
    }

    public void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getIdcardnum() {
        return idcardnum;
    }

    public void setIdcardnum(String idcardnum) {
        this.idcardnum = idcardnum;
    }

    public String getShop_code() {
        return shop_code;
    }

    public void setShop_code(String shop_code) {
        this.shop_code = shop_code;
    }

    public String getBxm_id() {
        return bxm_id;
    }

    public void setBxm_id(String bxm_id) {
        this.bxm_id = bxm_id;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getModeltype() {
        return modeltype;
    }

    public void setModeltype(String modeltype) {
        this.modeltype = modeltype;
    }
}

==> adscounter-facade-1.2.9-sources.jar: com/bxm/adscounter/facade/model/AdGroupCountMsg.java <==
package com.bxm.adscounter.facade.model;

import java.io.Serializable;

/**
 * <p> 广告组统计数据参数 </p>
 *
 * @Author: JandMin
 * @since: 1.0.0
 * @Date: 2018/8/9
 */
public class AdGroupCountMsg implements Serializable{
    private static final long serialVersionUID = -757734782728494378L;
    /**
     * ip地址
     */
    private String ipAddress;
    /**
     * 其它页面信息
     */
    private String param;
    /**
     * 手机号
     */
    private String phone;
    /**
     * 身份证号码
     */
    private String idcardnum;
    /**
     * 广告组标志
     */
    private String shop_code;
    /**
     * 记录ID
     */
    private String bxm_id;
    /**
     * 状态
     */
    private String status;
    /**
     * 类型
     */
    private String modeltype;

    /**
     * 券码通知类型：1使用，2激活
     */
    private String action_type;

    public String getIpAddress() {
        return ipAddress;
    }

    public void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getIdcardnum() {
        return idcardnum;
    }

    public void setIdcardnum(String idcardnum) {
        this.idcardnum = idcardnum;
    }

    public String getShop_code() {
        return shop_code;
    }

    public void setShop_code(String shop_code) {
        this.shop_code = shop_code;
    }

    public String getBxm_id() {
        return bxm_id;
    }

    public void setBxm_id(String bxm_id) {
        this.bxm_id = bxm_id;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getModeltype() {
        return modeltype;
    }

    public void setModeltype(String modeltype) {
        this.modeltype = modeltype;
    }

    public String getAction_type() {
        return action_type;
    }

    public void setAction_type(String action_type) {
        this.action_type = action_type;
    }
}
